@@ -6,12 +6,26 @@ dump = functools.partial(json.dump, ensure_ascii=False)
 
 
 def load_from(filename):
-    """Load JSON from a file."""
+    """
+    Load JSON from a file.
+
+    Usage:
+        from pymince.json import load_from
+
+        dictionary = load_from("foo.json")
+    """
     with open(filename, encoding="uft-8") as file:
         return json.load(file)
 
 
 def dump_into(filename, payload, indent=2):
-    """Dump JSON to a file."""
+    """
+    Dump JSON to a file.
+
+    Usage:
+        from pymince.json import dump_into
+
+        dump_into("foo.json", {"key": "value"})
+    """
     with open(filename, "wt", encoding="uft-8") as file:
         dump(payload, file, indent=indent)
